<?php

declare(strict_types=1);

namespace Drupal\joinup_group\Entity;

use Drupal\joinup_workflow\EntityWorkflowStateTrait;
use Drupal\message\Entity\Message;

/**
 * Bundle class for announcement messages.
 */
class Announcement extends Message implements AnnouncementInterface {

  use EntityWorkflowStateTrait;
  use GroupContentTrait;

  /**
   * {@inheritdoc}
   */
  public function setSubject(string $subject): AnnouncementInterface {
    $this->set('subject', $subject);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getSubject(): ?string {
    return $this->get('subject')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setBody(string $body): AnnouncementInterface {
    $this->set('body', $body);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getBody(): ?string {
    return $this->get('body')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function getBodyFormat(): string {
    $template = $this->getTemplate();
    $text = $template->get('text');
    if (!isset($text[0])) {
      throw new \RuntimeException("The 'announcement' message template should have a single text item");
    }
    return $text[0]['format'];
  }

  /**
   * {@inheritdoc}
   */
  public function getWorkflowStateFieldName(): string {
    return 'state';
  }

  /**
   * {@inheritdoc}
   */
  public function getText($langcode = NULL, $delta = NULL): array {
    $text = parent::getText($langcode, $delta);

    // Replace the text with the processed announcement body.
    if (isset($text[0])) {
      $build = [
        '#type' => 'processed_text',
        '#text' => $this->getBody(),
        '#format' => $this->getBodyFormat(),
      ];
      $body = \Drupal::service('renderer')->renderPlain($build);
      $text[0] = $this->processArguments($this->getArguments(), [$body])[0];
    }

    return $text;
  }

  /**
   * Returns the group reference field name.
   *
   * @return string
   *   The group reference field name.
   */
  protected function getGroupFieldName(): string {
    return 'group';
  }

}
